@@ -6,4 +6,4 @@ from .flecha import Flecha
 from .monopolo import Monopolo
 from .paralelepipedo import Paralelepipedo
 from .spines import Spines
-from .tetrahedro import Tetrahedro
\ No newline at end of file
+from .tetraedro import Tetraedro
\ No newline at end of file
